@@ -32,7 +32,7 @@ class MarketHTTP(HTTPManager):
             signed=False,
         )
         return res
-    
+
     async def get_spot_orderbook(
         self,
         product_symbol: str,
@@ -50,7 +50,7 @@ class MarketHTTP(HTTPManager):
             signed=False,
         )
         return res
-    
+
     async def get_spot_trades(
         self,
         product_symbol: str,
@@ -61,7 +61,7 @@ class MarketHTTP(HTTPManager):
         }
         if limit is not None:
             payload["limit"] = limit
-            
+
         res = await self._request(
             method="GET",
             path=SpotMarket.TRADES,
@@ -69,7 +69,7 @@ class MarketHTTP(HTTPManager):
             signed=False,
         )
         return res
-    
+
     async def get_kline(
         self,
         product_symbol: str,
@@ -85,10 +85,12 @@ class MarketHTTP(HTTPManager):
             payload["startTime"] = start_time
         if limit is not None:
             payload["limit"] = limit
-            
+
         res = await self._request(
             method="GET",
-            path=SpotMarket.KLINE if self.ptm.get_exchange_type(Common.BINANCE) == BinanceExchangeType.SPOT else FuturesMarket.KLINE,
+            path=SpotMarket.KLINE
+            if self.ptm.get_exchange_type(Common.BINANCE) == BinanceExchangeType.SPOT
+            else FuturesMarket.KLINE,
             query=payload,
             signed=False,
         )
