@@ -12,3 +12,9 @@ class FuturesTrade(str, Enum):
 
     def __str__(self) -> str:
         return self.value
+
+class SpotTrade(str, Enum):
+    PLACE_SPOT_ORDER = "/api/v3/order"
+
+    def __str__(self) -> str:
+        return self.value
\ No newline at end of file
